@@ -19,14 +19,13 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 4054 2008-07-21 17:11:44Z joanied $"
-__version__   = "$Revision: 4054 $"
-__date__      = "$Date: 2008-07-21 13:11:44 -0400 (Mon, 21 Jul 2008) $"
+__id__        = "$Id: flat_review.py 4104 2008-08-15 18:41:16Z joanied $"
+__version__   = "$Revision: 4104 $"
+__date__      = "$Date: 2008-08-15 14:41:16 -0400 (Fri, 15 Aug 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import re
-import sys
 
 import pyatspi
 import braille
@@ -597,11 +596,6 @@ class Context:
     WRAP_TOP_BOTTOM = 1 << 1
     WRAP_ALL        = (WRAP_LINE | WRAP_TOP_BOTTOM)
 
-    # A minimal chunk to jump around should we not really know where we
-    # are going.
-    #
-    GRID_SIZE = 7
-
     def __init__(self, script):
         """Create a new Context that will be used for handling flat
         review mode.
@@ -730,34 +724,6 @@ class Context:
         #
         self.targetCharInfo = None
 
-
-    def visible(self,
-                ax, ay, awidth, aheight,
-                bx, by, bwidth, bheight):
-        """Returns true if any portion of region 'a' is in region 'b'
-        """
-        highestBottom = min(ay + aheight, by + bheight)
-        lowestTop = max(ay, by)
-
-        leftMostRightEdge = min(ax + awidth, bx + bwidth)
-        rightMostLeftEdge = max(ax, bx)
-
-        visible = False
-
-        if (lowestTop <= highestBottom) \
-           and (rightMostLeftEdge <= leftMostRightEdge):
-            visible = True
-        elif (aheight == 0):
-            if (awidth == 0):
-                visible = (lowestTop == highestBottom) \
-                          and (leftMostRightEdge == rightMostLeftEdge)
-            else:
-                visible = leftMostRightEdge <= rightMostLeftEdge
-        elif (awidth == 0):
-            visible = (lowestTop <= highestBottom)
-
-        return visible
-
     def clip(self,
              ax, ay, awidth, aheight,
              bx, by, bwidth, bheight):
@@ -819,9 +785,9 @@ class Context:
             else:
                 [x, y, width, height] = text.getRangeExtents( \
                           substringStartOffset, substringEndOffset, 0)
-                if self.visible(x, y, width, height,
-                                cliprect.x, cliprect.y,
-                                cliprect.width, cliprect.height):
+                if self.script.visible(x, y, width, height,
+                                       cliprect.x, cliprect.y,
+                                       cliprect.width, cliprect.height):
 
                     anyVisible = True
 
@@ -1094,10 +1060,10 @@ class Context:
         #
         extents = icomponent.getExtents(0)
 
-        if not self.visible(extents.x, extents.y,
-                            extents.width, extents.height,
-                            cliprect.x, cliprect.y,
-                            cliprect.width, cliprect.height):
+        if not self.script.visible(extents.x, extents.y,
+                                   extents.width, extents.height,
+                                   cliprect.x, cliprect.y,
+                                   cliprect.width, cliprect.height):
             return []
 
         debug.println(
@@ -1143,9 +1109,9 @@ class Context:
             [width, height] = iimage.getImageSize()
 
             if (width != 0) and (height != 0) \
-                   and self.visible(x, y, width, height,
-                                    cliprect.x, cliprect.y,
-                                    cliprect.width, cliprect.height):
+                   and self.script.visible(x, y, width, height,
+                                           cliprect.x, cliprect.y,
+                                           cliprect.width, cliprect.height):
 
                 clipping = self.clip(x, y, width, height,
                                      cliprect.x, cliprect.y,
@@ -1216,91 +1182,6 @@ class Context:
 
         return zones
 
-    def getShowingDescendants(self, parent):
-        """Given a parent that manages its descendants, return a list of
-        Accessible children that are actually showing.  This algorithm
-        was inspired a little by the srw_elements_from_accessible logic
-        in Gnopernicus, and makes the assumption that the children of
-        an object that manages its descendants are arranged in a row
-        and column format.
-        """
-
-        if not parent:
-            return []
-
-        try:
-            icomponent = parent.queryComponent()
-        except NotImplementedError:
-            return []
-
-        descendants = []
-
-        parentExtents = icomponent.getExtents(0)
-
-        # [[[TODO: WDW - HACK related to GAIL bug where table column
-        # headers seem to be ignored:
-        # http://bugzilla.gnome.org/show_bug.cgi?id=325809.  The
-        # problem is that this causes getAccessibleAtPoint to return
-        # the cell effectively below the real cell at a given point,
-        # making a mess of everything.  So...we just manually add in
-        # showing headers for now.  The remainder of the logic below
-        # accidentally accounts for this offset, yet it should also
-        # work when bug 325809 is fixed.]]]
-        #
-        try:
-            table = parent.queryTable()
-        except NotImplementedError:
-            table = None
-            
-        if table:
-            for i in range(0, table.nColumns):
-                header = table.getColumnHeader(i)
-                if header:
-                    extents = header.queryComponent().getExtents(0)
-                    stateset = header.getState()
-                    if stateset.contains(pyatspi.STATE_SHOWING) \
-                       and (extents.x >= 0) and (extents.y >= 0) \
-                       and (extents.width > 0) and (extents.height > 0) \
-                       and self.visible(extents.x, extents.y,
-                                        extents.width, extents.height,
-                                        parentExtents.x, parentExtents.y,
-                                        parentExtents.width,
-                                        parentExtents.height):
-                        descendants.append(header)
-
-        # This algorithm goes left to right, top to bottom while attempting
-        # to do *some* optimization over queries.  It could definitely be
-        # improved.
-        #
-        currentY = parentExtents.y
-        while currentY < (parentExtents.y + parentExtents.height):
-            currentX = parentExtents.x
-            minHeight = sys.maxint
-            while currentX < (parentExtents.x + parentExtents.width):
-                child = icomponent.getAccessibleAtPoint(currentX,
-                                                            currentY,
-                                                            0)
-                if child:
-                    extents = child.queryComponent().getExtents(0)
-                    if extents.x >= 0 and extents.y >= 0:
-                        newX = extents.x + extents.width
-                        minHeight = min(minHeight, extents.height)
-                        if not descendants.count(child):
-                            descendants.append(child)
-                    else:
-                        newX = currentX + self.GRID_SIZE
-                else:
-                    newX = currentX + self.GRID_SIZE
-                if newX <= currentX:
-                    currentX += self.GRID_SIZE
-                else:
-                    currentX = newX
-            if minHeight == sys.maxint:
-                minHeight = self.GRID_SIZE
-            currentY += minHeight
-
-        return descendants
-
     def getShowingZones(self, root):
         """Returns a list of all interesting, non-intersecting, regions
         that are drawn on the screen.  Each element of the list is the
@@ -1383,11 +1264,11 @@ class Context:
                 zones = self.getZonesFromAccessible(root, rootexts)
         except NotImplementedError:
             pass
-        
-        stateset = root.getState()
-        if stateset.contains(pyatspi.STATE_MANAGES_DESCENDANTS) \
-           and (root.childCount > 50):
-            for child in self.getShowingDescendants(root):
+
+        showingDescendants = \
+            self.script.getShowingDescendants(root)
+        if len(showingDescendants):
+            for child in showingDescendants:
                 zones.extend(self.getShowingZones(child))
         else:
             for i in range(0, root.childCount):
