@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: script.py 3882 2008-05-07 18:22:10Z richb $"
-__version__   = "$Revision: 3882 $"
-__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__id__        = "$Id: script.py 3971 2008-06-11 00:54:46Z joanied $"
+__version__   = "$Revision: 3971 $"
+__date__      = "$Date: 2008-06-10 20:54:46 -0400 (Tue, 10 Jun 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -38,7 +38,6 @@ import orca.orca_state as orca_state
 import orca.speech as speech
 import orca.speechserver as speechserver
 import orca.settings as settings
-import orca.chnames as chnames
 
 from orca.orca_i18n import _ # for gettext support
 
@@ -97,7 +96,7 @@ class Script(default.Script):
 
         # Pylint is confused and flags several errors of the type:
         #
-        # E1101:282:Script.__init__: Module 'orca.rolenames' has no 
+        # E1101:282:Script.__init__: Module 'orca.rolenames' has no
         # 'ROLE_CALENDAR_VIEW' member
         #
         # So for now, we just disable these errors in this method.
@@ -181,8 +180,8 @@ class Script(default.Script):
         keyBindings.add(
             keybindings.KeyBinding(
                 "n",
-                1 << settings.MODIFIER_ORCA,
-                1 << settings.MODIFIER_ORCA,
+                settings.defaultModifierMask,
+                settings.ORCA_MODIFIER_MASK,
                 self.inputEventHandlers["toggleReadMailHandler"]))
         return keyBindings
 
@@ -263,7 +262,7 @@ class Script(default.Script):
                             # Only speak the screen label if we haven't already
                             # done so.
                             #
-                            if text and not self.setupLabels.has_key(label):
+                            if text and label not in self.setupLabels:
                                 # Translators: this is the name of a setup
                                 # assistant window/screen in Evolution.
                                 #
@@ -292,7 +291,7 @@ class Script(default.Script):
             # label, then just ignore it.
             #
             text = self.getDisplayedText(label)
-            if text and not self.setupLabels.has_key(label):
+            if text and label not in self.setupLabels:
                 # Most of the Setup Assistant screens have a useful piece
                 # of text starting with the word "Please". We want to speak
                 # these. For the first screen, the useful piece of text
@@ -460,7 +459,7 @@ class Script(default.Script):
                 done = True
 
         # If there is anything left unspoken, speak it now.
-        # 
+        #
         if len(string) != 0:
             string = self.adjustForRepeats(string)
             if string.isupper():
@@ -525,9 +524,6 @@ class Script(default.Script):
             self.speakTextIndentation(obj, string)
         line = self.adjustForRepeats(string)
 
-        if self.speakNewLine(obj):
-            speech.speak(chnames.getCharacterName("\n"), None, False)
-
         if self.speakBlankLine(obj):
             # Translators: "blank" is a short word to mean the
             # user has navigated to an empty line.
@@ -591,7 +587,7 @@ class Script(default.Script):
         brailleGen = self.brailleGenerator
         speechGen = self.speechGenerator
 
-        # Save the previous role hierarchy list for possible comparison 
+        # Save the previous role hierarchy list for possible comparison
         # in section 8).
         #
         self.lastRolesList = self.rolesList
@@ -631,7 +627,6 @@ class Script(default.Script):
             self.presentMessageLine(event.source, newLocusOfFocus)
             return
 
-
         # 2) Mail view: current message pane: "standard" mail header lines.
         #
         # Check if the focus is in the From:, To:, Subject: or Date: headers
@@ -666,7 +661,8 @@ class Script(default.Script):
             parent = obj.parent
             if parent.getRole() == pyatspi.ROLE_TABLE:
                 parentTable = parent.queryTable()
-                row = parentTable.getRowAtIndex(obj.getIndexInParent())
+                index = self.getCellIndex(obj)
+                row = parentTable.getRowAtIndex(index)
                 utterances = []
                 regions = []
                 for i in range(0, parentTable.nColumns):
@@ -722,12 +718,12 @@ class Script(default.Script):
 
             parent = event.source.parent
             parentTable = parent.queryTable()
-            row = parentTable.getRowAtIndex(event.source.getIndexInParent())
-            column = \
-                parentTable.getColumnAtIndex(event.source.getIndexInParent())
+            index = self.getCellIndex(event.source)
+            row = parentTable.getRowAtIndex(index)
+            column = parentTable.getColumnAtIndex(index)
 
             # If we are on the same row, then just speak/braille the table
-            # cell as if settings.readTableCellRow was False. 
+            # cell as if settings.readTableCellRow was False.
             # See bug #503874 for more details.
             #
             if self.lastMessageRow == row:
@@ -740,7 +736,7 @@ class Script(default.Script):
             # cells (the user has moved focus up or down the list, or just
             # deleted a message), or just the current one (focus has moved
             # left or right in the same row). If we at the start or the end
-            # of the message header list and the row and column haven't 
+            # of the message header list and the row and column haven't
             # changed, then speak all the table cells.
             #
             justDeleted = False
@@ -1186,9 +1182,9 @@ class Script(default.Script):
             # We are getting extra (bogus?) "focus:" events from Evolution
             # when we type the first character at the beginning of a line.
             # If the last input event was a keyboard event and the parent
-            # of the locusOfFocus and the event.source are the same, and 
+            # of the locusOfFocus and the event.source are the same, and
             # the last roles hierarchy is the same as this one and
-            # the last key pressed wasn't a navigation key, then just 
+            # the last key pressed wasn't a navigation key, then just
             # ignore it. See bug #490317 for more details.
             #
             if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
@@ -1200,6 +1196,15 @@ class Script(default.Script):
                                        "Home", "End", "Return"]:
                         return
 
+                    # If the last keyboard event was a "same line" 
+                    # navigation key, then pass this event onto the
+                    # onCaretMoved() method in the parent class for
+                    # speaking. See bug #516565 for more details.
+                    #
+                    if lastKey in ["Left", "Right", "Home", "End"]:
+                        default.Script.onCaretMoved(self, event)
+                        return
+
             self.message_panel = event.source.parent.parent
 
             self.presentMessageLine(event.source, newLocusOfFocus)
@@ -1340,63 +1345,6 @@ class Script(default.Script):
         default.Script.locusOfFocusChanged(self, event,
                                            oldLocusOfFocus, newLocusOfFocus)
 
-    def speakNewLine(self, obj):
-        """Returns True if a newline should be spoken.
-           Otherwise, returns False.
-        """
-
-        # Get the the AccessibleText interrface.
-        try:
-            text = obj.queryText()
-        except NotImplementedError:
-            return False
-
-        # Was a left or right-arrow key pressed?
-        if not (orca_state.lastInputEvent and \
-                orca_state.lastInputEvent.__dict__.has_key("event_string")):
-            return False
-
-        lastKey = orca_state.lastNonModifierKeyEvent.event_string
-        if lastKey != "Left" and lastKey != "Right":
-            return False
-
-        # Was a control key pressed?
-        mods = orca_state.lastInputEvent.modifiers
-        isControlKey = mods & (1 << pyatspi.MODIFIER_CONTROL)
-
-        # Get the line containing the caret
-        caretOffset = text.caretOffset
-        line = text.getTextAtOffset(caretOffset, \
-            pyatspi.TEXT_BOUNDARY_LINE_START)
-        lineStart = line[1]
-        lineEnd = line[2]
-
-        if isControlKey:  # control-right-arrow or control-left-arrow
-
-            # Get the word containing the caret.
-            word = text.getTextAtOffset(caretOffset, \
-                pyatspi.TEXT_BOUNDARY_WORD_START)
-            wordStart = word[1]
-            wordEnd = word[2]
-
-            if lastKey == "Right":
-                if wordStart == lineStart:
-                    return True
-            else:
-                if wordEnd == lineEnd:
-                    return True
-
-        else:  # right arrow or left arrow
-
-            if lastKey == "Right":
-                if caretOffset == lineStart:
-                    return True
-            else:
-                if caretOffset == lineEnd:
-                    return True
-
-        return False
-
     def speakBlankLine(self, obj):
         """Returns True if a blank line should be spoken.
         Otherwise, returns False.
@@ -1413,7 +1361,7 @@ class Script(default.Script):
         line = text.getTextAtOffset(caretOffset, \
             pyatspi.TEXT_BOUNDARY_LINE_START)
 
-        debug.println(debug.LEVEL_FINEST, 
+        debug.println(debug.LEVEL_FINEST,
             "speakBlankLine: start=%d, end=%d, line=<%s>" % \
             (line[1], line[2], line[0]))
 
@@ -1424,7 +1372,6 @@ class Script(default.Script):
         else:
             return False
 
-
     def onStateChanged(self, event):
         """Called whenever an object's state changes.  We are only
         interested in "object:state-changed:showing" events for any
@@ -1466,7 +1413,7 @@ class Script(default.Script):
                     # seen this panel, then handle it.
                     #
                     elif event.source.getRole() == pyatspi.ROLE_PANEL and \
-                        not self.setupPanels.has_key(event.source):
+                        event.source not in self.setupPanels:
                         self.handleSetupAssistantPanel(event.source)
                         self.setupPanels[event.source] = True
                         break
@@ -1479,7 +1426,7 @@ class Script(default.Script):
         default.Script.onStateChanged(self, event)
 
     def onFocus(self, event):
-        """Called whenever an object gets focus.  
+        """Called whenever an object gets focus.
 
         Arguments:
         - event: the Event
@@ -1489,9 +1436,9 @@ class Script(default.Script):
         # two focus events:  One for the index of the new message prior to
         # deletion and one for the index of the new message after deletion.
         # This causes us to speak the message after the one that gets focus
-        # prior to speaking the actual message that gets focus. 
+        # prior to speaking the actual message that gets focus.
         # See bug #347964.
-        # 
+        #
         if isinstance(orca_state.lastInputEvent,
                       input_event.KeyboardEvent):
             string = orca_state.lastNonModifierKeyEvent.event_string
@@ -1505,10 +1452,10 @@ class Script(default.Script):
                    self.isDesiredFocusedItem(oldLocusOfFocus, rolesList):
                     parent = event.source.parent
                     parentTable = parent.queryTable()
-                    newRow = parentTable.getRowAtIndex( \
-                                  event.source.getIndexInParent())
-                    oldRow = parentTable.getRowAtIndex( \
-                                  oldLocusOfFocus.getIndexInParent())
+                    newIndex = self.getCellIndex(event.source)
+                    newRow = parentTable.getRowAtIndex(newIndex)
+                    oldIndex = self.getCellIndex(oldLocusOfFocus)
+                    oldRow = parentTable.getRowAtIndex(oldIndex)
                     nRows = parentTable.nRows
                     if (newRow != oldRow) and (oldRow != nRows):
                         return
