@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3971 2008-06-11 00:54:46Z joanied $"
-__version__   = "$Revision: 3971 $"
-__date__      = "$Date: 2008-06-10 20:54:46 -0400 (Tue, 10 Jun 2008) $"
+__id__        = "$Id: settings.py 4109 2008-08-18 16:24:49Z wwalker $"
+__version__   = "$Revision: 4109 $"
+__date__      = "$Date: 2008-08-18 12:24:49 -0400 (Mon, 18 Aug 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -85,6 +85,7 @@ import pyatspi
 import debug
 from acss import ACSS
 from orca_i18n import _           # for gettext support
+from orca_i18n import Q_          # to provide qualified translatable strings
 
 # These are the settings that Orca supports the user customizing.
 #
@@ -98,6 +99,7 @@ userCustomizableSettings = [
     "readTableCellRow",
     "enableSpeechIndentation",
     "enableEchoByWord",
+    "enableEchoBySentence",
     "enableKeyEcho",
     "enablePrintableKeys",
     "enableModifierKeys",
@@ -105,8 +107,11 @@ userCustomizableSettings = [
     "enableFunctionKeys",
     "enableActionKeys",
     "enableNavigationKeys",
+    "enableTutorialMessages",
     "enableBraille",
     "enableBrailleGrouping",
+    "disableBrailleEOL",
+    "brailleEOLIndicator",
     "brailleVerbosityLevel",
     "brailleRolenameStyle",
     "brailleSelectorIndicator",
@@ -116,6 +121,7 @@ userCustomizableSettings = [
     "enableMagLiveUpdating",
     "enableMagCursor",
     "enableMagCursorExplicitSize",
+    "magHideCursor",
     "magCursorSize",
     "magCursorColor",
     "enableMagCrossHair",
@@ -165,7 +171,16 @@ userCustomizableSettings = [
     "enableContractedBraille",
     "brailleContractionTable",
     "enableMouseReview",
-    "mouseDwellDelay"
+    "mouseDwellDelay",
+    "speakCellCoordinates",
+    "speakCellSpan",
+    "speakCellHeaders",
+    "skipBlankCells",
+    "largeObjectTextLength",
+    "wrappedStructuralNavigation",
+    "presentRequiredState",
+    "brailleRequiredStateString",
+    "speechRequiredStateString"
 ]
 
 # The name of the module that hold the user interface for the main window
@@ -281,6 +296,13 @@ httpServerPort          = 0
 #
 maxHttpServerRetries    = 20
 
+# Whether or not to use DBUS.
+#
+if os.getenv("DBUS_SESSION_BUS_ADDRESS"):
+    useDBus = True
+else:
+    useDBus = False
+
 # Whether or not recording is enabled via the HTTP server. 
 #
 enableRemoteLogging     = False
@@ -331,6 +353,11 @@ enableBrailleGrouping   = False
 #
 enableBrailleMonitor    = False
 
+# string to indicate end of printed line for braille displays:
+#
+disableBrailleEOL = False
+brailleEOLIndicator = " $l"
+
 # Strings used to indicate checkbox/radio button states in braille:
 #
 brailleCheckBoxIndicators = ["< >", "<x>", "<->"]
@@ -354,6 +381,10 @@ enableMagCursor                  = True
 #
 enableMagCursorExplicitSize      = False
 
+# If True, hide the system cursor.
+#
+magHideCursor                    = False
+
 # Size of the magnification cursor (in pixels).
 #
 magCursorSize                    = 32
@@ -503,6 +534,12 @@ magTargetDisplay                 = ''
 #
 enableEchoByWord        = False
 
+# if True, enable word echo.
+# Note that it is allowable for both enableEchoByWord and enableEchoBySentence
+# to be True.
+#
+enableEchoBySentence    = False
+
 # If True, enable key echo.
 # Note that it is allowable for both enableEchoByWord and enableKeyEcho
 # to be True
@@ -533,6 +570,9 @@ enableActionKeys        = True
 #
 enableNavigationKeys    = False
 
+# If True, roles that have tutorial strings defined will be spoken.
+enableTutorialMessages = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -563,13 +603,33 @@ readTableCellRow    = True
 
 # If True, enable speaking of progress bar updates.
 #
-enableProgressBarUpdates = False
+enableProgressBarUpdates = True
 
 # The interval (in seconds) between speaking progress bar updates. A value
 # of zero means that progress bar updates should not be spoken at all.
 #
 progressBarUpdateInterval = 10
 
+# Whether or not to present the 'read only' attribute of text areas
+# if we can detect they are read only or not.
+#
+presentReadOnlyText = True
+
+# Translators: this is used to indicate the user is in a text
+# area that is not editable.  It is meant to be spoken to the user.
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+speechReadOnlyString = Q_("text|read only")
+
+# Translators: this is used to indicate the user is in a text
+# area that is not editable.  It is meant to be a short abbreviation
+# to be presented on the braille display.
+#
+# ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+#
+brailleReadOnlyString = Q_("text|rdonly")
+
 # The complete list of possible text attributes.
 #
 allTextAttributes = \
@@ -938,6 +998,12 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
+# Translators: see the regular expression note above.  This is for a
+# version of Thunderbird, which chooses to now call itself by a different
+# name.
+#
+setScriptMapping(re.compile(_('Shredder')), "Thunderbird")
+
 # Translators: see the regular expression note above.  This is for
 # the Thunderbird e-mail application.
 #
@@ -995,6 +1061,33 @@ brailleContractionTable = ''
 # 
 useCollection = True
 
+# Whether or not to speak the cell's coordinates when navigating
+# from cell to cell in a table.
+#
+speakCellCoordinates = True
+
+# Whether or not to speak the number of cells spanned by a cell
+# that occupies more than one row or column of a table.
+#
+speakCellSpan = True
+
+# Whether or not to announce the header that applies to the current
+# when navigating from cell to cell in a table.
+#
+speakCellHeaders = True
+
+# Whether blank cells should be skipped when navigating in a table
+# using table navigation commands.
+#
+skipBlankCells = False
+
+# The minimum size in characters to be considered a "large object"
+# or "chunk" for structural navigation.
+#
+largeObjectTextLength = 75
+
+# Whether to wrap around the document when structural navigation is used.
+wrappedStructuralNavigation = True
 
 # Report object under mouse.
 #
@@ -1052,3 +1145,24 @@ ALL_BUT_NUMLOCK_MODIFIER_MASK = (1 << MODIFIER_ORCA |
 # among headings (H) and the Help menu (Alt+H).
 #
 defaultModifierMask = NON_LOCKING_MODIFIER_MASK
+
+# Whether or not we should present objects with STATE_REQUIRED to
+# the user. Currently, this is only seen with ARIA widgets.
+#
+presentRequiredState = False
+
+# Translators: Certain objects (such as form controls on web pages)
+# can have STATE_REQUIRED set on them to inform the user that this
+# field must be filled out. This string is the default string which
+# will be spoken and displayed in braille to indicate this state is
+# present.
+#
+brailleRequiredStateString = _("required")
+
+# Translators: Certain objects (such as form controls on web pages)
+# can have STATE_REQUIRED set on them to inform the user that this
+# field must be filled out. This string is the default string which
+# will be spoken and displayed in braille to indicate this state is
+# present.
+#
+speechRequiredStateString = _("required")
