@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 4072 2008-08-01 20:47:02Z wwalker $"
-__version__   = "$Revision: 4072 $"
-__date__      = "$Date: 2008-08-01 16:47:02 -0400 (Fri, 01 Aug 2008) $"
+__id__        = "$Id: speechgenerator.py 4098 2008-08-12 17:56:14Z joanied $"
+__version__   = "$Revision: 4098 $"
+__date__      = "$Date: 2008-08-12 13:56:14 -0400 (Tue, 12 Aug 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -209,7 +209,7 @@ class SpeechGenerator:
         else:
             return []
 
-    def _getSpeechForObjectRole(self, obj, role=None):
+    def getSpeechForObjectRole(self, obj, role=None):
         if (obj.getRole() != pyatspi.ROLE_UNKNOWN):
             return [rolenames.getSpeechForRoleName(obj, role)]
         else:
@@ -314,7 +314,7 @@ class SpeechGenerator:
             if name != label:
                 utterances.extend(name)
             utterances.extend(self._getSpeechForAllTextSelection(obj))
-            utterances.extend(self._getSpeechForObjectRole(obj, role))
+            utterances.extend(self.getSpeechForObjectRole(obj, role))
 
         utterances.extend(self._getSpeechForObjectAvailability(obj))
 
@@ -440,10 +440,10 @@ class SpeechGenerator:
                 utterances.extend(name)
             if obj.getRole() == pyatspi.ROLE_TABLE_CELL:
                 utterances.extend(
-                  self._getSpeechForObjectRole(
+                  self.getSpeechForObjectRole(
                     obj, pyatspi.ROLE_CHECK_BOX))
             else:
-                utterances.extend(self._getSpeechForObjectRole(obj))
+                utterances.extend(self.getSpeechForObjectRole(obj))
             utterances.append(checkedState)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
             utterances.extend(self._getSpeechForRequiredObject(obj))
@@ -524,7 +524,7 @@ class SpeechGenerator:
             utterances.extend(name)
 
         if not already_focused:
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
 
         utterances.extend(self._getSpeechForObjectAvailability(obj))
 
@@ -670,7 +670,7 @@ class SpeechGenerator:
             if name != label:
                 utterances.extend(name)
             utterances.extend(self._getSpeechForAllTextSelection(obj))
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
 
             # If this application has more than one unfocused alert or
             # dialog window, then speak '<m> unfocused dialogs'
@@ -1001,7 +1001,7 @@ class SpeechGenerator:
             utterances.append(settings.speechReadOnlyString)
 
         if obj.getRole() != pyatspi.ROLE_PARAGRAPH:
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
 
         [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
         utterances.append(text)
@@ -1104,7 +1104,7 @@ class SpeechGenerator:
             name = self._getSpeechForObjectName(obj)
             if name != label:
                 utterances.extend(name)
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
 
         utterances.append(percentage)
 
@@ -1170,7 +1170,7 @@ class SpeechGenerator:
             #utterances.extend(self._getSpeechForObjectLabel(obj))
             utterances.extend(self._getSpeechForObjectName(obj))
             utterances.append(selectionState)
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
             utterances.extend(self._getSpeechForObjectAvailability(obj))
         else:
             utterances.append(selectionState)
@@ -1278,7 +1278,7 @@ class SpeechGenerator:
             #
             if not utterances:
                 utterances.extend(self._getSpeechForObjectName(obj))
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
             utterances.append(valueString)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
             utterances.extend(self._getSpeechForRequiredObject(obj))
@@ -1333,7 +1333,7 @@ class SpeechGenerator:
             utterances.extend(self._getSpeechForObjectLabel(obj))
             if not utterances:
                 utterances.extend(self._getSpeechForObjectName(obj))
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
             utterances.append(valueString)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
 
@@ -1719,7 +1719,7 @@ class SpeechGenerator:
             name = self._getSpeechForObjectName(obj)
             if name != label:
                 utterances.extend(name)
-            utterances.extend(self._getSpeechForObjectRole(obj))
+            utterances.extend(self.getSpeechForObjectRole(obj))
             utterances.append(checkedState)
             utterances.extend(self._getSpeechForObjectAvailability(obj))
         else:
